@@ -34,6 +34,7 @@ void defaults()
 {
 	state.update_interval = CHK_INTERVAL;
 	state.standard_free = 0;
+	state.mb = 0;
 	safecopy(state.proc_mem_filename, PROC_MEM, 256);
 	withdrawn = 0;
 	iconic = 0; 
@@ -55,6 +56,7 @@ void usage()
         printf("-V              print version and exit\n");
         printf("-h -H -help     print this message\n");
         printf("-u <secs>       the update interval in seconds\n");
+        printf("-mb             the display is in MBytes\n");
         printf("-display <name> the name of the display to use\n");
         printf("-position <xy>  position on the screen (geometry)\n");
         printf("-withdrawn      start in withdrawn shape (for WindowMaker)\n");
@@ -75,7 +77,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-        printf("asmem : AfterStep memory utilization monitor version 1.1\n");
+        printf("asmem : AfterStep memory utilization monitor version 1.2\n");
 }               
 
 void    parsecmdline(int argc, char *argv[])
@@ -95,6 +97,8 @@ void    parsecmdline(int argc, char *argv[])
                                 pushed_in=0;
                         } else if (!strncmp(argument,"-free",5)) {
                                 state.standard_free=1;
+                        } else if (!strncmp(argument,"-mb",3)) {
+                                state.mb=1;
                         } else if (!strncmp(argument,"-u",2)) {
                                 if (++i >= argc)
                                         usage();
