@@ -84,7 +84,8 @@ void draw_window(Window win)
 			0,
 			0
 			);
-	if (state.fresh.total > (999999 * 1024))
+	if ( (state.fresh.total > (999999 * 1024)) 
+			|| state.mb )
 		total = state.fresh.total / 1024 / 1024;
 	else
 		total = state.fresh.total / 1024;
@@ -117,7 +118,8 @@ void draw_window(Window win)
 		free_mem = state.fresh.free
 			+state.fresh.buffers
 			+state.fresh.cached;
-	if (state.fresh.total > (999999 * 1024))
+	if ( (state.fresh.total > (999999 * 1024))
+			|| state.mb )
 		available = free_mem / 1024 / 1024;
 	else
 		available = free_mem / 1024;
@@ -239,7 +241,8 @@ void draw_window(Window win)
 				);
 	}
 
-	if (state.fresh.swap_total > (999999*1024))
+	if ( (state.fresh.swap_total > (999999*1024))
+			|| state.mb )
 		total = state.fresh.swap_total / 1024 / 1024;
 	else
 		total = state.fresh.swap_total / 1024;
@@ -266,7 +269,8 @@ void draw_window(Window win)
 				);
 	}
 
-	if (state.fresh.swap_total > (999999*1024))
+	if ( (state.fresh.swap_total > (999999*1024))
+			|| state.mb )
 		available = state.fresh.swap_free / 1024 / 1024;
 	else
 		available = state.fresh.swap_free / 1024;
